@@ -4,10 +4,11 @@ Description: Omit
 LastEditors: Rustle Karl
 LastEditTime: 2022.02.03 12:37
 """
-from .common import Entity, create_common_files
+from .common import Entity
+from .render import render_templates
 
-TEMPLATE_ARTICLE_STATIC = Entity(
-    "assets/templates/article_static.yaml",
+TEMPLATE_ARTICLE_SETTINGS = Entity(
+    "assets/templates/article_settings.yaml",
     """\
 tags: ["标签"]
 series: [ "系列"]
@@ -32,22 +33,20 @@ TEMPLATE_ARTICLE_CONTENT = Entity(
 
 
 def notes():
-    create_common_files(
-        [
-            "quickstart",  # 安装/卸载/基础用法
-            "docs",  # 基础语法/知识/原理
+    render_templates(
+        "notes",
+        folder=[
+            "assets/images",  # 笔记配图
+            "assets/templates",  # 笔记模板
+            "docs",  # 基础语法
             "libraries",  # 库
             "libraries/standard",  # 标准库
             "libraries/tripartite",  # 第三方库
-            "assets/images",  # 图片
-            "assets/templates",  # 笔记模板
+            "quickstart",  # 基础用法
             "src",  # 源码示例
-            "src/docs",  # 源码示例
-            "src/quickstart",  # 源码示例
+            "src/docs",  # 基础语法源码示例
             "src/libraries/standard",  # 标准库源码示例
             "src/libraries/tripartite",  # 第三方库源码示例
-        ]
+            "src/quickstart",  # 基础用法源码示例
+        ],
     )
-
-    TEMPLATE_ARTICLE_STATIC.create()
-    TEMPLATE_ARTICLE_CONTENT.create()
